@@ -1,20 +1,15 @@
 import sys
 
+import ipaddress
+
 # pylint: skip-file
 
-is_py2 = sys.version_info[0] == 2
+if sys.version_info[0] == 2:
+    def compat_ip_address(address):
+        if isinstance(address, bytes):
+            address = address.decode()
+        return ipaddress.ip_address(address)
 
-is_py3_3_or_better = (
-    sys.version_info[0] >= 3 and sys.version_info[1] >= 3)
-
-if is_py2 and not is_py3_3_or_better:
-    import ipaddr as ipaddress  # pylint:disable=F0401
-    ipaddress.ip_address = ipaddress.IPAddress
-else:
-    import ipaddress  # pylint:disable=F0401
-
-
-if is_py2:
     int_from_byte = ord
 
     FileNotFoundError = IOError
@@ -25,8 +20,10 @@ if is_py2:
         return 0
 
     byte_from_int = chr
-
 else:
+    def compat_ip_address(address):
+        return ipaddress.ip_address(address)
+
     int_from_byte = lambda x: x
 
     FileNotFoundError = FileNotFoundError
