@@ -126,6 +126,10 @@ class Decoder(object):  # pylint: disable=too-few-public-methods
         if not type_num:
             (type_num, new_offset) = self._read_extended(new_offset)
 
+        if type_num not in self._type_decoder:
+            raise InvalidDatabaseError('Unexpected type number ({type}) '
+                                       'encountered'.format(type=type_num))
+
         (size, new_offset) = self._size_from_ctrl_byte(
             ctrl_byte, new_offset, type_num)
         return self._type_decoder[type_num](self, size, new_offset)
